@@ -27,13 +27,13 @@ module Data.Ranged.RangedSet (
 
 import Data.Ranged.Boundaries
 import Data.Ranged.Ranges
-#if __GLASGOW_HASKELL__ >= 800
+#if MIN_VERSION_base(4,9,0) && !MIN_VERSION_base(4,11,0)
 import Data.Semigroup
-#elif __GLASGOW_HASKELL__ < 710
+#elif !MIN_VERSION_base(4,9,0)
 import Data.Monoid
 #endif
 
-import Data.List
+import Data.List hiding (and, null)
 
 infixl 7 -/\-
 infixl 6 -\/-, -!-
@@ -44,18 +44,18 @@ infixl 5 -<=-, -<-, -?-
 newtype DiscreteOrdered v => RSet v = RSet {rSetRanges :: [Range v]}
    deriving (Eq, Show, Ord)
 
-#if __GLASGOW_HASKELL__ >= 800
+#if MIN_VERSION_base(4,9,0)
 instance DiscreteOrdered a => Semigroup (RSet a) where
     (<>) = rSetUnion
+#endif
 
 instance DiscreteOrdered a => Monoid (RSet a) where
+#if MIN_VERSION_base(4,9,0)
     mappend = (<>)
-    mempty = rSetEmpty
 #else
-instance DiscreteOrdered a => Monoid (RSet a) where
     mappend = rSetUnion
-    mempty = rSetEmpty
 #endif
+    mempty = rSetEmpty
 
 -- | Determine if the ranges in the list are both in order and non-overlapping.
 -- If so then they are suitable input for the unsafeRangedSet function.
